@@ -1,6 +1,7 @@
 import threading
 from typing import List
 from google.protobuf.descriptor import FieldDescriptor, FileDescriptor, MethodDescriptor
+from google.protobuf.json_format import MessageToDict
 from grpc import Server, StatusCode
 from delphai_utils.logging import logging
 from grpc_requests import Client
@@ -63,7 +64,8 @@ class GatewayServer(threading.Thread):
     input = {**request.path_params, **body}
     handler = self.handlers[path]
     try:
-      output = self.client.request(handler['service'], handler['method'], input)
+      raw_output = self.client.request(handler['service'], handler['method'], input, raw_output=True)
+      output = MessageToDict(raw_output, including_default_value_fields=True, preserving_proto_field_name=True)
       return JSONResponse(output)
     except Exception as ex:
       grpc_status = ex._state.code.name
@@ -101,6 +103,10 @@ class GatewayServer(threading.Thread):
     app = Starlette(debug=True, routes=routes, exception_handlers={HTTPException: self.http_exception})
     config = Config()
     config.bind = [f'0.0.0.0:{self.port}']
+    config.loglevel = 'INFO'
+    config.accesslog = '.'
+    config.errorlog = '.'
+    logging.getLogger('hypercorn.access').setLevel(logging.INFO)
     asyncio.run(serve(app, config))
 
 
